@@ -151,11 +151,13 @@ class TestDeployOvercloud(fakes.TestDeployOvercloud):
             'CinderPassword': 'password',
             'ExtraConfig': '{}',
             'GlancePassword': 'password',
+            'GnocchiPassword': 'password',
             'HAProxyStatsPassword': 'password',
             'HeatPassword': 'password',
             'HeatStackDomainAdminPassword': 'password',
             'HypervisorNeutronPhysicalBridge': 'br-ex',
             'HypervisorNeutronPublicInterface': 'nic1',
+            'MysqlClustercheckPassword': 'password',
             'NeutronAllowL3AgentFailover': False,
             'NeutronDhcpAgentsPerNetwork': 1,
             'NeutronDnsmasqOptions': 'dhcp-option-force=26,1400',
@@ -173,6 +175,8 @@ class TestDeployOvercloud(fakes.TestDeployOvercloud):
             'SwiftHashSuffix': 'password',
             'SwiftPassword': 'password',
             'DeployIdentifier': 123456789,
+            'UpdateIdentifier': None,
+            'StackAction': 'UPDATE',
         }
 
         def _custom_create_params_env(parameters):
@@ -304,17 +308,20 @@ class TestDeployOvercloud(fakes.TestDeployOvercloud):
             'CeilometerMeteringSecret': 'password',
             'CeilometerPassword': 'password',
             'CephAdminKey': 'cephx_key',
+            'CephClientKey': 'cephx_key',
             'CephClusterFSID': 'uuid',
             'CephMonKey': 'cephx_key',
             'CephStorageCount': 3,
             'CinderPassword': 'password',
             'ExtraConfig': '{}',
             'GlancePassword': 'password',
+            'GnocchiPassword': 'password',
             'HAProxyStatsPassword': 'password',
             'HeatPassword': 'password',
             'HeatStackDomainAdminPassword': 'password',
             'HypervisorNeutronPhysicalBridge': 'br-ex',
             'HypervisorNeutronPublicInterface': 'nic1',
+            'MysqlClustercheckPassword': 'password',
             'NeutronAllowL3AgentFailover': False,
             'NeutronDhcpAgentsPerNetwork': 1,
             'NeutronDnsmasqOptions': 'dhcp-option-force=26,1400',
@@ -335,6 +342,8 @@ class TestDeployOvercloud(fakes.TestDeployOvercloud):
             'SwiftHashSuffix': 'password',
             'SwiftPassword': 'password',
             'DeployIdentifier': 123456789,
+            'UpdateIdentifier': None,
+            'StackAction': 'CREATE',
         }
 
         def _custom_create_params_env(parameters):
@@ -877,6 +886,20 @@ class TestDeployOvercloud(fakes.TestDeployOvercloud):
                           '/fake/path', mock.ANY, mock.ANY, mock.ANY,
                           mock.ANY, mock.ANY)
 
+    @mock.patch('tripleoclient.v1.overcloud_deploy.DeployOvercloud.'
+                '_heat_deploy', autospec=True)
+    def test_try_overcloud_deploy_show_missing_file(
+            self, mock_heat_deploy_func):
+        mock_heat_deploy_func.side_effect = [
+            six.moves.urllib.error.URLError('/fake/path not found')
+            for stack_file in constants.OVERCLOUD_YAML_NAMES]
+        try:
+            self.cmd._try_overcloud_deploy_with_compat_yaml(
+                '/fake/path', mock.ANY, mock.ANY, mock.ANY,
+                mock.ANY, mock.ANY)
+        except ValueError as value_error:
+            self.assertIn('/fake/path', str(value_error))
+
     @mock.patch('tripleoclient.utils.create_tempest_deployer_input',
                 autospec=True)
     @mock.patch('tripleoclient.utils.create_overcloudrc', autospec=True)
@@ -969,31 +992,58 @@ class TestDeployOvercloud(fakes.TestDeployOvercloud):
         mock_create_tempest_deployer_input.assert_called_with()
 
     @mock.patch('tripleoclient.utils.get_password')
+    @mock.patch('tripleoclient.constants.SERVICE_LIST',
+                {'nova': {'password_field': 'OVERCLOUD_NOVA_PASSWORD'}})
     @mock.patch('os_cloud_config.keystone.initialize')
     @mock.patch('os_cloud_config.utils.clients.get_keystone_client')
     def test_keystone_init(self, mock_gkc, mock_init, mock_gp):
         mock_ksc = mock.Mock()
         mock_gkc.return_value = mock_ksc
-        mock_ksc.users.find.return_value = True
-        sips = mock.Mock()
-        sips.get.return_value = None
+        mock_ksc.services.find.return_value = True
+        stack = mock.MagicMock()
+        stack.to_dict.return_value = fakes.FAKE_STACK
         ip = '192.0.2.1'
         overcloud_deploy.DeployOvercloud(None, None)._keystone_init(ip, ip,
-                                                                    None, sips)
+                                                                    None,
+                                                                    stack)
         self.assertFalse(mock_init.called)
 
     @mock.patch('tripleoclient.utils.get_password')
+    @mock.patch('tripleoclient.constants.SERVICE_LIST',
+                {'nova': {'password_field': 'OVERCLOUD_NOVA_PASSWORD'}})
     @mock.patch('os_cloud_config.keystone.setup_endpoints')
     @mock.patch('os_cloud_config.keystone.initialize')
     @mock.patch('os_cloud_config.utils.clients.get_keystone_client')
     def test_keystone_init_occ(self, mock_gkc, mock_init, mock_se, mock_gp):
         mock_ksc = mock.Mock()
         mock_gkc.return_value = mock_ksc
-        mock_ksc.users.find.side_effect = kscexc.NotFound()
-        sips = mock.Mock()
-        sips.get.return_value = None
+        mock_ksc.services.find.side_effect = kscexc.NotFound()
+        stack = mock.Mock()
+        stack.to_dict.return_value = fakes.FAKE_STACK
         ip = '192.0.2.1'
         args = mock.Mock()
         overcloud_deploy.DeployOvercloud(None, None)._keystone_init(ip, ip,
-                                                                    args, sips)
+                                                                    args,
+                                                                    stack)
+        self.assertTrue(mock_init.called)
+
+    @mock.patch('tripleoclient.utils.get_password')
+    @mock.patch('tripleoclient.constants.SERVICE_LIST',
+                {'nova': {'password_field': 'OVERCLOUD_NOVA_PASSWORD'},
+                 'unexistent': {'password_field': 'OVERCLOUD_NOVA_PASSWORD'}})
+    @mock.patch('os_cloud_config.keystone.setup_endpoints')
+    @mock.patch('os_cloud_config.keystone.initialize')
+    @mock.patch('os_cloud_config.utils.clients.get_keystone_client')
+    def test_keystone_init_occ_w_entry_not_in_endpoint_map(
+            self, mock_gkc, mock_init, mock_se, mock_gp):
+        mock_ksc = mock.Mock()
+        mock_gkc.return_value = mock_ksc
+        mock_ksc.services.find.side_effect = kscexc.NotFound()
+        stack = mock.Mock()
+        stack.to_dict.return_value = fakes.FAKE_STACK
+        ip = '192.0.2.1'
+        args = mock.Mock()
+        overcloud_deploy.DeployOvercloud(None, None)._keystone_init(ip, ip,
+                                                                    args,
+                                                                    stack)
         self.assertTrue(mock_init.called)
